sepadd -- SEPA Direct Debit XML
===============================

.. image:: https://travis-ci.org/raphaelm/python-sepadd.svg?branch=master
   :target: https://travis-ci.org/raphaelm/python-sepadd

This is a python implementation to generate SEPA direct debit XML files.

For now, this is basically a properly packaged, python 3 tested version 
of the `PySepaDD`_ implementation that was released by The Congressus under the MIT license.
Thanks for your work!

Limitations
-----------

* Currently, only SEPA PAIN.008.001.02 is supported.

Credits and License
-------------------

Maintainer: Raphael Michel <mail@raphaelmichel.de>

Original Author: Congressus

License: MIT

.. _PySepaDD: https://github.com/congressus/PySepaDD
